@@ -5,7 +5,7 @@
 # Copyright (C) 2002       Masato Taruishi <taru@debian.org>
 # Copyright (C) 2006-2008  Junichi Uekawa <dancer@debian.org>
 # Copyright (C) 2007       Famelis George <famelis@otenet.gr>
-# Copyright (C) 2008-2018  Francesco Poli <invernomuto@paranoici.org>
+# Copyright (C) 2008-2019  Francesco Poli <invernomuto@paranoici.org>
 # Copyright (C) 2009-2010  Ryan Niebur <ryan@debian.org>
 # Copyright (C) 2013       Google Inc
 #
@@ -66,8 +66,9 @@ class AppConfig
       _(" -C <apt.conf>    : Additional apt.conf file to use.\n"),
       _(" -F               : Automatically pin all buggy packages.\n"),
       _(" -N               : Never automatically pin packages.\n"),
-      _(" -y               : Assume that you select yes for all questions.\n"),
-      _(" -n               : Assume that you select no for all questions.\n"),
+      _(" -y               : Assume yes for all questions.\n"),
+      _(" -n               : Assume no for all questions.\n"),
+      _(" -a               : Assume the default reply for all questions.\n"),
       _(" -d               : Debug.\n"),
       _(" -h               : Display this help and exit.\n"),
       _(" -v               : Show version number and exit.\n"),
@@ -123,6 +124,7 @@ class AppConfig
     @apt_conf = nil
 
     @yes = nil
+    @default_reply = nil
     @force_pin = nil
 
     @arrow = "->"
@@ -134,6 +136,7 @@ class AppConfig
   attr_accessor :severity, :stats, :quiet, :title
   attr_accessor :show_downgrade, :hostname, :tag, :fbugs, :querystep, :parsestep
   attr_accessor :frontend, :pin_priority, :yes, :ignore_regexp, :force_pin
+  attr_accessor :default_reply
   attr_reader :command, :parser, :querybts, :ignore_bugs, :system_ignore_bugs
   attr_reader :browser, :arrow, :cmd_prefix, :ext_user
 
@@ -173,6 +176,7 @@ class AppConfig
                            ['--force-no-pin', '-N', GetoptLong::NO_ARGUMENT],
                            ['--force-yes', '-y', GetoptLong::NO_ARGUMENT],
                            ['--force-no', '-n', GetoptLong::NO_ARGUMENT],
+                           ['--force-default', '-a', GetoptLong::NO_ARGUMENT],
                            ['--debug', '-d', GetoptLong::NO_ARGUMENT]
                            );
 
@@ -216,8 +220,13 @@ class AppConfig
           $DEBUG = 1
         when '--force-yes'
           @yes = true
+          @default_reply = nil
         when '--force-no'
           @yes = false
+          @default_reply = nil
+        when '--force-default'
+          @yes = nil
+          @default_reply = true
         when '--force-pin'
           @force_pin = true
         when '--force-no-pin'
@@ -468,11 +477,15 @@ class Viewer
         if @config.force_pin
           a = "p"
         else
-          if @config.yes.nil?
-            a = @config.frontend.ask ask_str
+          if @config.default_reply
+            a = ""
           else
-            a = "y" if @config.yes
-            a = "n" if ! @config.yes
+            if @config.yes.nil?
+              a = @config.frontend.ask ask_str
+            else
+              a = "y" if @config.yes
+              a = "n" if ! @config.yes
+            end
           end
         end
         if a.nil?
@@ -1318,6 +1331,7 @@ class ConsoleFrontend
 
   def yes_or_no?(msg, default = true)
     return @config.yes if ! @config.yes.nil?
+    return default if @config.default_reply
     while true
       msgyn = "#{msg}"
       if default == true
